@@ -4,12 +4,25 @@ html_generators.django
 Utilities for using html_generators within a django project.
 This is the only module within html_generators that has any django 
 dependencies.
-'''
 
+As well as providing some new/wrapper functionality, we also provide 
+convenient aliases for some of django's built-in template tags/filters.
+
+Some of the contents of this module have names that clash with
+standard python classes/functions, so we intend you to import 
+this entire module with a convenient alias:
+import html_generators.django as hd
+'''
 from ._base import HTMLGenerator
+from django.templatetags.static import static
+from django.template.defaultfilters import date
 from django.template.loader import render_to_string
 
-class DjangoTemplate(HTMLGenerator):
+__all__ = [
+	'date', 'static', 'Template',
+]
+
+class Template(HTMLGenerator):
 	'''
 	Renders a django template with given request/context.
 
@@ -36,3 +49,6 @@ class DjangoTemplate(HTMLGenerator):
 			request=self.request, 
 			using=self.using
 		)
+
+# backward compatible alias
+DjangoTemplate = Template
